Class: Aws::OpsWorks::Layer

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/layer.rbs,
lib/aws-sdk-opsworks/layer.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, options = {}) ⇒ Layer #initialize(options = {}) ⇒ Layer

Returns a new instance of Layer.

Overloads:

  • #initialize(id, options = {}) ⇒ Layer

    Parameters:

    • id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Layer

    Options Hash (options):

    • :id (required, String)
    • :client (Client)


13
14
15
# File 'sig/layer.rbs', line 13

def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#arnString

The Amazon Resource Number (ARN) of a layer.

Returns:

  • (String)


21
# File 'sig/layer.rbs', line 21

def arn: () -> ::String

#attributesHash<String,String>

The layer attributes.

For the HaproxyStatsPassword, MysqlRootPassword, and GangliaPassword attributes, OpsWorks Stacks returns *****FILTERED***** instead of the actual value

For an ECS Cluster layer, OpsWorks Stacks the EcsClusterArn attribute is set to the cluster's ARN.

Returns:

  • (Hash<String,String>)


39
# File 'sig/layer.rbs', line 39

def attributes: () -> ::Hash[("EcsClusterArn" | "EnableHaproxyStats" | "HaproxyStatsUrl" | "HaproxyStatsUser" | "HaproxyStatsPassword" | "HaproxyHealthCheckUrl" | "HaproxyHealthCheckMethod" | "MysqlRootPassword" | "MysqlRootPasswordUbiquitous" | "GangliaUrl" | "GangliaUser" | "GangliaPassword" | "MemcachedMemory" | "NodejsVersion" | "RubyVersion" | "RubygemsVersion" | "ManageBundler" | "BundlerVersion" | "RailsStack" | "PassengerVersion" | "Jvm" | "JvmVersion" | "JvmOptions" | "JavaAppServer" | "JavaAppServerVersion"), ::String]

#auto_assign_elastic_ipsBoolean

Whether to automatically assign an Elastic IP address to the layer's instances. For more information, see How to Edit a Layer.

Returns:

  • (Boolean)


66
# File 'sig/layer.rbs', line 66

def auto_assign_elastic_ips: () -> bool

#auto_assign_public_ipsBoolean

For stacks that are running in a VPC, whether to automatically assign a public IP address to the layer's instances. For more information, see How to Edit a Layer.

Returns:

  • (Boolean)


69
# File 'sig/layer.rbs', line 69

def auto_assign_public_ips: () -> bool

#clientClient

Returns:



230
# File 'lib/aws-sdk-opsworks/layer.rb', line 230

def client: () -> Client

#cloud_watch_logs_configurationTypes::CloudWatchLogsConfiguration

The Amazon CloudWatch Logs configuration settings for the layer.



42
# File 'sig/layer.rbs', line 42

def cloud_watch_logs_configuration: () -> Types::CloudWatchLogsConfiguration

#created_atString

Date when the layer was created.

Returns:

  • (String)


78
# File 'sig/layer.rbs', line 78

def created_at: () -> ::String

#custom_instance_profile_arnString

The ARN of the default IAM profile to be used for the layer's EC2 instances. For more information about IAM ARNs, see Using Identifiers.

Returns:

  • (String)


45
# File 'sig/layer.rbs', line 45

def custom_instance_profile_arn: () -> ::String

#custom_jsonString

A JSON formatted string containing the layer's custom stack configuration and deployment attributes.

Returns:

  • (String)


48
# File 'sig/layer.rbs', line 48

def custom_json: () -> ::String

#custom_recipesTypes::Recipes

A LayerCustomRecipes object that specifies the layer's custom recipes.

Returns:



75
# File 'sig/layer.rbs', line 75

def custom_recipes: () -> Types::Recipes

#custom_security_group_idsArray<String>

An array containing the layer's custom security group IDs.

Returns:

  • (Array<String>)


51
# File 'sig/layer.rbs', line 51

def custom_security_group_ids: () -> ::Array[::String]

#dataTypes::Layer

Returns the data for this Aws::OpsWorks::Layer. Calls Client#describe_layers if #data_loaded? is false.

Returns:



96
# File 'sig/layer.rbs', line 96

def data: () -> Types::Layer

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



99
# File 'sig/layer.rbs', line 99

def data_loaded?: () -> bool

#default_recipesTypes::Recipes

OpsWorks Stacks supports five lifecycle events: setup, configuration, deploy, undeploy, and shutdown. For each layer, OpsWorks Stacks runs a set of standard recipes for each event. You can also provide custom recipes for any or all layers and events. OpsWorks Stacks runs custom event recipes after the standard recipes. LayerCustomRecipes specifies the custom recipes for a particular layer to be run in response to each of the five events.

To specify a recipe, use the cookbook's directory name in the repository followed by two colons and the recipe name, which is the recipe's file name without the .rb extension. For example: phpapp2::dbsetup specifies the dbsetup.rb recipe in the repository's phpapp2 folder.

Returns:



72
# File 'sig/layer.rbs', line 72

def default_recipes: () -> Types::Recipes

#default_security_group_namesArray<String>

An array containing the layer's security group names.

Returns:

  • (Array<String>)


54
# File 'sig/layer.rbs', line 54

def default_security_group_names: () -> ::Array[::String]

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


layer.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


103
# File 'sig/layer.rbs', line 103

def delete: (

#enable_auto_healingBoolean

Whether auto healing is disabled for the layer.

Returns:

  • (Boolean)


63
# File 'sig/layer.rbs', line 63

def enable_auto_healing: () -> bool

#idString

Returns:

  • (String)


18
# File 'sig/layer.rbs', line 18

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


394
395
396
# File 'lib/aws-sdk-opsworks/layer.rb', line 394

def identifiers
  { id: @id }
end

#install_updates_on_bootBoolean

Whether to install operating system and package updates when the instance boots. The default value is true. If this value is set to false, you must then update your instances manually by using CreateDeployment to run the update_dependencies stack command or manually running yum (Amazon Linux) or apt-get (Ubuntu) on the instances.

We strongly recommend using the default value of true, to ensure that your instances have the latest security updates.

Returns:

  • (Boolean)


81
# File 'sig/layer.rbs', line 81

def install_updates_on_boot: () -> bool

#layer_idString

The layer ID.

Returns:

  • (String)


27
# File 'sig/layer.rbs', line 27

def layer_id: () -> ::String

#lifecycle_event_configurationTypes::LifecycleEventConfiguration

A LifeCycleEventConfiguration object that specifies the Shutdown event configuration.



87
# File 'sig/layer.rbs', line 87

def lifecycle_event_configuration: () -> Types::LifecycleEventConfiguration

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::OpsWorks::Layer. Returns self making it possible to chain methods.

layer.reload.data

Returns:

  • (self)


92
# File 'sig/layer.rbs', line 92

def load: () -> self

#nameString

The layer name. Layer names can be a maximum of 32 characters.

Returns:

  • (String)


33
# File 'sig/layer.rbs', line 33

def name: () -> ::String

#packagesArray<String>

An array of Package objects that describe the layer's packages.

Returns:

  • (Array<String>)


57
# File 'sig/layer.rbs', line 57

def packages: () -> ::Array[::String]

#shortnameString

The layer short name.

Returns:

  • (String)


36
# File 'sig/layer.rbs', line 36

def shortname: () -> ::String

#stackStack?

Returns:



108
# File 'sig/layer.rbs', line 108

def stack: () -> Stack?

#stack_idString

The layer stack ID.

Returns:

  • (String)


24
# File 'sig/layer.rbs', line 24

def stack_id: () -> ::String

#typeString

The layer type.

Returns:

  • (String)


30
# File 'sig/layer.rbs', line 30

def type: () -> ("aws-flow-ruby" | "ecs-cluster" | "java-app" | "lb" | "web" | "php-app" | "rails-app" | "nodejs-app" | "memcached" | "db-master" | "monitoring-master" | "custom")

#use_ebs_optimized_instancesBoolean

Whether the layer uses Amazon EBS-optimized instances.

Returns:

  • (Boolean)


84
# File 'sig/layer.rbs', line 84

def use_ebs_optimized_instances: () -> bool

#volume_configurationsArray<Types::VolumeConfiguration>

A VolumeConfigurations object that describes the layer's Amazon EBS volumes.

Returns:



60
# File 'sig/layer.rbs', line 60

def volume_configurations: () -> ::Array[Types::VolumeConfiguration]

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::OpsWorks::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/aws-sdk-opsworks/layer.rb', line 344

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end