Class: Aws::OpsWorks::Stack

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/stack.rbs,
lib/aws-sdk-opsworks/stack.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, options = {}) ⇒ Stack #initialize(options = {}) ⇒ Stack

Returns a new instance of Stack.

Overloads:

  • #initialize(id, options = {}) ⇒ Stack

    Parameters:

    • id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Stack

    Options Hash (options):

    • :id (required, String)
    • :client (Client)


13
14
15
# File 'sig/stack.rbs', line 13

def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#agent_versionString

The agent version. This parameter is set to LATEST for auto-update. or a version number for a fixed agent version.

Returns:

  • (String)


84
# File 'sig/stack.rbs', line 84

def agent_version: () -> ::String

#arnString

The stack's ARN.

Returns:

  • (String)


27
# File 'sig/stack.rbs', line 27

def arn: () -> ::String

#attributesHash<String,String>

The stack's attributes.

Returns:

  • (Hash<String,String>)


36
# File 'sig/stack.rbs', line 36

def attributes: () -> ::Hash[("Color"), ::String]

#chef_configurationTypes::ChefConfiguration

A ChefConfiguration object that specifies whether to enable Berkshelf and the Berkshelf version. For more information, see Create a New Stack.



63
# File 'sig/stack.rbs', line 63

def chef_configuration: () -> Types::ChefConfiguration

#clientClient

Returns:



225
# File 'lib/aws-sdk-opsworks/stack.rb', line 225

def client: () -> Client

#configuration_managerTypes::StackConfigurationManager

The configuration manager.



60
# File 'sig/stack.rbs', line 60

def configuration_manager: () -> Types::StackConfigurationManager

#create_layer(options = {}) ⇒ Layer

Examples:

Request syntax with placeholder values


layer = stack.create_layer({
  type: "aws-flow-ruby", # required, accepts aws-flow-ruby, ecs-cluster, java-app, lb, web, php-app, rails-app, nodejs-app, memcached, db-master, monitoring-master, custom
  name: "String", # required
  shortname: "String", # required
  attributes: {
    "EcsClusterArn" => "String",
  },
  cloud_watch_logs_configuration: {
    enabled: false,
    log_streams: [
      {
        log_group_name: "String",
        datetime_format: "String",
        time_zone: "LOCAL", # accepts LOCAL, UTC
        file: "String",
        file_fingerprint_lines: "String",
        multi_line_start_pattern: "String",
        initial_position: "start_of_file", # accepts start_of_file, end_of_file
        encoding: "ascii", # accepts ascii, big5, big5hkscs, cp037, cp424, cp437, cp500, cp720, cp737, cp775, cp850, cp852, cp855, cp856, cp857, cp858, cp860, cp861, cp862, cp863, cp864, cp865, cp866, cp869, cp874, cp875, cp932, cp949, cp950, cp1006, cp1026, cp1140, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1256, cp1257, cp1258, euc_jp, euc_jis_2004, euc_jisx0213, euc_kr, gb2312, gbk, gb18030, hz, iso2022_jp, iso2022_jp_1, iso2022_jp_2, iso2022_jp_2004, iso2022_jp_3, iso2022_jp_ext, iso2022_kr, latin_1, iso8859_2, iso8859_3, iso8859_4, iso8859_5, iso8859_6, iso8859_7, iso8859_8, iso8859_9, iso8859_10, iso8859_13, iso8859_14, iso8859_15, iso8859_16, johab, koi8_r, koi8_u, mac_cyrillic, mac_greek, mac_iceland, mac_latin2, mac_roman, mac_turkish, ptcp154, shift_jis, shift_jis_2004, shift_jisx0213, utf_32, utf_32_be, utf_32_le, utf_16, utf_16_be, utf_16_le, utf_7, utf_8, utf_8_sig
        buffer_duration: 1,
        batch_count: 1,
        batch_size: 1,
      },
    ],
  },
  custom_instance_profile_arn: "String",
  custom_json: "String",
  custom_security_group_ids: ["String"],
  packages: ["String"],
  volume_configurations: [
    {
      mount_point: "String", # required
      raid_level: 1,
      number_of_disks: 1, # required
      size: 1, # required
      volume_type: "String",
      iops: 1,
      encrypted: false,
    },
  ],
  enable_auto_healing: false,
  auto_assign_elastic_ips: false,
  auto_assign_public_ips: false,
  custom_recipes: {
    setup: ["String"],
    configure: ["String"],
    deploy: ["String"],
    undeploy: ["String"],
    shutdown: ["String"],
  },
  install_updates_on_boot: false,
  use_ebs_optimized_instances: false,
  lifecycle_event_configuration: {
    shutdown: {
      execution_timeout: 1,
      delay_until_elb_connections_drained: false,
    },
  },
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :type (required, String)

    The layer type. A stack cannot have more than one built-in layer of the same type. It can have any number of custom layers. Built-in layers are not available in Chef 12 stacks.

  • :name (required, String)

    The layer name, which is used by the console. Layer names can be a maximum of 32 characters.

  • :shortname (required, String)

    For custom layers only, use this parameter to specify the layer's short name, which is used internally by OpsWorks Stacks and by Chef recipes. The short name is also used as the name for the directory where your app files are installed. It can have a maximum of 32 characters, which are limited to the alphanumeric characters, '-', '_', and '.'.

    Built-in layer short names are defined by OpsWorks Stacks. For more information, see the Layer Reference.

  • :attributes (Hash<String,String>)

    One or more user-defined key-value pairs to be added to the stack attributes.

    To create a cluster layer, set the EcsClusterArn attribute to the cluster's ARN.

  • :cloud_watch_logs_configuration (Types::CloudWatchLogsConfiguration)

    Specifies CloudWatch Logs configuration options for the layer. For more information, see CloudWatchLogsLogStream.

  • :custom_instance_profile_arn (String)

    The ARN of an IAM profile to be used for the layer's EC2 instances. For more information about IAM ARNs, see Using Identifiers.

  • :custom_json (String)

    A JSON-formatted string containing custom stack configuration and deployment attributes to be installed on the layer's instances. For more information, see Using Custom JSON. This feature is supported as of version 1.7.42 of the CLI.

  • :custom_security_group_ids (Array<String>)

    An array containing the layer custom security group IDs.

  • :packages (Array<String>)

    An array of Package objects that describes the layer packages.

  • :volume_configurations (Array<Types::VolumeConfiguration>)

    A VolumeConfigurations object that describes the layer's Amazon EBS volumes.

  • :enable_auto_healing (Boolean)

    Whether to disable auto healing for the layer.

  • :auto_assign_elastic_ips (Boolean)

    Whether to automatically assign an Elastic IP address to the layer's instances. For more information, see How to Edit a Layer.

  • :auto_assign_public_ips (Boolean)

    For stacks that are running in a VPC, whether to automatically assign a public IP address to the layer's instances. For more information, see How to Edit a Layer.

  • :custom_recipes (Types::Recipes)

    A LayerCustomRecipes object that specifies the layer custom recipes.

  • :install_updates_on_boot (Boolean)

    Whether to install operating system and package updates when the instance boots. The default value is true. To control when updates are installed, set this value to false. You must then update your instances manually by using CreateDeployment to run the update_dependencies stack command or by manually running yum (Amazon Linux) or apt-get (Ubuntu) on the instances.

    To ensure that your instances have the latest security updates, we strongly recommend using the default value of true.

  • :use_ebs_optimized_instances (Boolean)

    Whether to use Amazon EBS-optimized instances.

  • :lifecycle_event_configuration (Types::LifecycleEventConfiguration)

    A LifeCycleEventConfiguration object that you can use to configure the Shutdown event to specify an execution timeout and enable or disable Elastic Load Balancer connection draining.

Returns:



100
# File 'sig/stack.rbs', line 100

def create_layer: (

#created_atString

The date when the stack was created.

Returns:

  • (String)


78
# File 'sig/stack.rbs', line 78

def created_at: () -> ::String

#custom_cookbooks_sourceTypes::Source

Contains the information required to retrieve an app or cookbook from a repository. For more information, see Adding Apps or Cookbooks and Recipes.

Returns:



72
# File 'sig/stack.rbs', line 72

def custom_cookbooks_source: () -> Types::Source

#custom_jsonString

A JSON object that contains user-defined attributes to be added to the stack configuration and deployment attributes. You can use custom JSON to override the corresponding default stack configuration attribute values or to pass data to recipes. The string should be in the following format:

"{"key1": "value1", "key2": "value2",...}"

For more information on custom JSON, see Use Custom JSON to Modify the Stack Configuration Attributes.

Returns:

  • (String)


57
# File 'sig/stack.rbs', line 57

def custom_json: () -> ::String

#dataTypes::Stack

Returns the data for this Aws::OpsWorks::Stack. Calls Client#describe_stacks if #data_loaded? is false.

Returns:



93
# File 'sig/stack.rbs', line 93

def data: () -> Types::Stack

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



96
# File 'sig/stack.rbs', line 96

def data_loaded?: () -> bool

#default_availability_zoneString

The stack's default Availability Zone. For more information, see Regions and Endpoints.

Returns:

  • (String)


51
# File 'sig/stack.rbs', line 51

def default_availability_zone: () -> ::String

#default_instance_profile_arnString

The ARN of an IAM profile that is the default profile for all of the stack's EC2 instances. For more information about IAM ARNs, see Using Identifiers.

Returns:

  • (String)


42
# File 'sig/stack.rbs', line 42

def default_instance_profile_arn: () -> ::String

#default_osString

The stack's default operating system.

Returns:

  • (String)


45
# File 'sig/stack.rbs', line 45

def default_os: () -> ::String

#default_root_device_typeString

The default root device type. This value is used by default for all instances in the stack, but you can override it when you create an instance. For more information, see Storage for the Root Device.

Returns:

  • (String)


81
# File 'sig/stack.rbs', line 81

def default_root_device_type: () -> ("ebs" | "instance-store")

#default_ssh_key_nameString

A default Amazon EC2 key pair for the stack's instances. You can override this value when you create or update an instance.

Returns:

  • (String)


75
# File 'sig/stack.rbs', line 75

def default_ssh_key_name: () -> ::String

#default_subnet_idString

The default subnet ID; applicable only if the stack is running in a VPC.

Returns:

  • (String)


54
# File 'sig/stack.rbs', line 54

def default_subnet_id: () -> ::String

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


stack.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


160
# File 'sig/stack.rbs', line 160

def delete: (

#hostname_themeString

The stack host name theme, with spaces replaced by underscores.

Returns:

  • (String)


48
# File 'sig/stack.rbs', line 48

def hostname_theme: () -> ::String

#idString

Returns:

  • (String)


18
# File 'sig/stack.rbs', line 18

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


581
582
583
# File 'lib/aws-sdk-opsworks/stack.rb', line 581

def identifiers
  { id: @id }
end

#layers(options = {}) ⇒ Layer::Collection

Examples:

Request syntax with placeholder values


layers = stack.layers({
  layer_ids: ["String"],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :layer_ids (Array<String>)

    An array of layer IDs that specify the layers to be described. If you omit this parameter, DescribeLayers returns a description of every layer in the specified stack.

Returns:



165
# File 'sig/stack.rbs', line 165

def layers: (

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::OpsWorks::Stack. Returns self making it possible to chain methods.

stack.reload.data

Returns:

  • (self)


89
# File 'sig/stack.rbs', line 89

def load: () -> self

#nameString

The stack name. Stack names can be a maximum of 64 characters.

Returns:

  • (String)


24
# File 'sig/stack.rbs', line 24

def name: () -> ::String

#regionString

The stack Amazon Web Services Region, such as ap-northeast-2. For more information about Amazon Web Services Regions, see Regions and Endpoints.

Returns:

  • (String)


30
# File 'sig/stack.rbs', line 30

def region: () -> ::String

#service_role_arnString

The stack Identity and Access Management (IAM) role.

Returns:

  • (String)


39
# File 'sig/stack.rbs', line 39

def service_role_arn: () -> ::String

#stack_idString

The stack ID.

Returns:

  • (String)


21
# File 'sig/stack.rbs', line 21

def stack_id: () -> ::String

#summaryStackSummary

Returns:



171
# File 'sig/stack.rbs', line 171

def summary: () -> StackSummary

#use_custom_cookbooksBoolean

Whether the stack uses custom cookbooks.

Returns:

  • (Boolean)


66
# File 'sig/stack.rbs', line 66

def use_custom_cookbooks: () -> bool

#use_opsworks_security_groupsBoolean

Whether the stack automatically associates the OpsWorks Stacks built-in security groups with the stack's layers.

Returns:

  • (Boolean)


69
# File 'sig/stack.rbs', line 69

def use_opsworks_security_groups: () -> bool

#vpc_idString

The VPC ID; applicable only if the stack is running in a VPC.

Returns:

  • (String)


33
# File 'sig/stack.rbs', line 33

def vpc_id: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::OpsWorks::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-opsworks/stack.rb', line 339

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end