Class: Aws::OpsWorks::Types::CreateDeploymentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpsWorks::Types::CreateDeploymentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opsworks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_id ⇒ String
The app ID.
-
#command ⇒ Types::DeploymentCommand
A
DeploymentCommandobject that specifies the deployment command and any associated arguments. -
#comment ⇒ String
A user-defined comment.
-
#custom_json ⇒ String
A string that contains user-defined, custom JSON.
-
#instance_ids ⇒ Array<String>
The instance IDs for the deployment targets.
-
#layer_ids ⇒ Array<String>
The layer IDs for the deployment targets.
-
#stack_id ⇒ String
The stack ID.
Instance Attribute Details
#app_id ⇒ String
The app ID. This parameter is required for app deployments, but not for other deployment commands.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1073 class CreateDeploymentRequest < Struct.new( :stack_id, :app_id, :instance_ids, :layer_ids, :command, :comment, :custom_json) SENSITIVE = [] include Aws::Structure end |
#command ⇒ Types::DeploymentCommand
A DeploymentCommand object that specifies the deployment command
and any associated arguments.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1073 class CreateDeploymentRequest < Struct.new( :stack_id, :app_id, :instance_ids, :layer_ids, :command, :comment, :custom_json) SENSITIVE = [] include Aws::Structure end |
#comment ⇒ String
A user-defined comment.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1073 class CreateDeploymentRequest < Struct.new( :stack_id, :app_id, :instance_ids, :layer_ids, :command, :comment, :custom_json) SENSITIVE = [] include Aws::Structure end |
#custom_json ⇒ String
A string that contains user-defined, custom JSON. You can use this parameter to override some corresponding default stack configuration JSON values. The string should be in the following format:
"{"key1": "value1", "key2": "value2",...}"
For more information about custom JSON, see Use Custom JSON to Modify the Stack Configuration Attributes and Overriding Attributes With Custom JSON.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1073 class CreateDeploymentRequest < Struct.new( :stack_id, :app_id, :instance_ids, :layer_ids, :command, :comment, :custom_json) SENSITIVE = [] include Aws::Structure end |
#instance_ids ⇒ Array<String>
The instance IDs for the deployment targets.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1073 class CreateDeploymentRequest < Struct.new( :stack_id, :app_id, :instance_ids, :layer_ids, :command, :comment, :custom_json) SENSITIVE = [] include Aws::Structure end |
#layer_ids ⇒ Array<String>
The layer IDs for the deployment targets.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1073 class CreateDeploymentRequest < Struct.new( :stack_id, :app_id, :instance_ids, :layer_ids, :command, :comment, :custom_json) SENSITIVE = [] include Aws::Structure end |
#stack_id ⇒ String
The stack ID.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1073 class CreateDeploymentRequest < Struct.new( :stack_id, :app_id, :instance_ids, :layer_ids, :command, :comment, :custom_json) SENSITIVE = [] include Aws::Structure end |