Class: Aws::OpsWorks::Types::CreateInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpsWorks::Types::CreateInstanceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opsworks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_version ⇒ String
The default OpsWorks Stacks agent version.
-
#ami_id ⇒ String
A custom AMI ID to be used to create the instance.
-
#architecture ⇒ String
The instance architecture.
-
#auto_scaling_type ⇒ String
For load-based or time-based instances, the type.
-
#availability_zone ⇒ String
The instance Availability Zone.
-
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
An array of
BlockDeviceMappingobjects that specify the instance's block devices. -
#ebs_optimized ⇒ Boolean
Whether to create an Amazon EBS-optimized instance.
-
#hostname ⇒ String
The instance host name.
-
#install_updates_on_boot ⇒ Boolean
Whether to install operating system and package updates when the instance boots.
-
#instance_type ⇒ String
The instance type, such as
t2.micro. -
#layer_ids ⇒ Array<String>
An array that contains the instance's layer IDs.
-
#os ⇒ String
The instance's operating system, which must be set to one of the following.
-
#root_device_type ⇒ String
The instance root device type.
-
#ssh_key_name ⇒ String
The instance's Amazon EC2 key-pair name.
-
#stack_id ⇒ String
The stack ID.
-
#subnet_id ⇒ String
The ID of the instance's subnet.
-
#tenancy ⇒ String
The instance's tenancy option.
-
#virtualization_type ⇒ String
The instance's virtualization type,
paravirtualorhvm.
Instance Attribute Details
#agent_version ⇒ String
The default OpsWorks Stacks agent version. You have the following options:
-
INHERIT- Use the stack's default agent version setting. -
version_number - Use the specified agent version. This value overrides the stack's default setting. To update the agent version, edit the instance configuration and specify a new version. OpsWorks Stacks installs that version on the instance.
The default setting is INHERIT. To specify an agent version, you
must use the complete version number, not the abbreviated number
shown on the console. For a list of available agent version numbers,
call DescribeAgentVersions. AgentVersion cannot be set to Chef 12.2.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#ami_id ⇒ String
A custom AMI ID to be used to create the instance. The AMI should be based on one of the supported operating systems. For more information, see Using Custom AMIs.
Os to Custom.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#architecture ⇒ String
The instance architecture. The default option is x86_64. Instance
types do not necessarily support both architectures. For a list of
the architectures that are supported by the different instance
types, see Instance Families and Types.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#auto_scaling_type ⇒ String
For load-based or time-based instances, the type. Windows stacks can use only time-based instances.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The instance Availability Zone. For more information, see Regions and Endpoints.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#block_device_mappings ⇒ Array<Types::BlockDeviceMapping>
An array of BlockDeviceMapping objects that specify the
instance's block devices. For more information, see Block Device
Mapping. Note that block device mappings are not supported for
custom AMIs.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized ⇒ Boolean
Whether to create an Amazon EBS-optimized instance.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#hostname ⇒ String
The instance host name. The following are character limits for instance host names.
-
Linux-based instances: 63 characters
-
Windows-based instances: 15 characters
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#install_updates_on_boot ⇒ Boolean
Whether to install operating system and package updates when the
instance boots. The default value is true. To control when updates
are installed, set this value to false. You must then update your
instances manually by using CreateDeployment to run the
update_dependencies stack command or by manually running yum
(Amazon Linux) or apt-get (Ubuntu) on the instances.
true to ensure
that your instances have the latest security updates.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type, such as t2.micro. For a list of supported
instance types, open the stack in the console, choose Instances,
and choose + Instance. The Size list contains the currently
supported types. For more information, see Instance Families and
Types. The parameter values that you use to specify the various
types are in the API Name column of the Available Instance
Types table.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#layer_ids ⇒ Array<String>
An array that contains the instance's layer IDs.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#os ⇒ String
The instance's operating system, which must be set to one of the following.
-
A supported Linux operating system: An Amazon Linux version, such as
Amazon Linux 2,Amazon Linux 2018.03,Amazon Linux 2017.09,Amazon Linux 2017.03,Amazon Linux 2016.09,Amazon Linux 2016.03,Amazon Linux 2015.09, orAmazon Linux 2015.03. -
A supported Ubuntu operating system, such as
Ubuntu 18.04 LTS,Ubuntu 16.04 LTS,Ubuntu 14.04 LTS, orUbuntu 12.04 LTS. -
CentOS Linux 7 -
Red Hat Enterprise Linux 7 -
A supported Windows operating system, such as
Microsoft Windows Server 2012 R2 Base,Microsoft Windows Server 2012 R2 with SQL Server Express,Microsoft Windows Server 2012 R2 with SQL Server Standard, orMicrosoft Windows Server 2012 R2 with SQL Server Web. -
A custom AMI:
Custom.
Not all operating systems are supported with all versions of Chef. For more information about the supported operating systems, see OpsWorks Stacks Operating Systems.
The default option is the current Amazon Linux version. If you set
this parameter to Custom, you must use the CreateInstance
action's AmiId parameter to specify the custom AMI that you want to
use. Block device mappings are not supported if the value is
Custom. For more information about how to use custom AMIs with
OpsWorks Stacks, see Using Custom AMIs.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#root_device_type ⇒ String
The instance root device type. For more information, see Storage for the Root Device.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#ssh_key_name ⇒ String
The instance's Amazon EC2 key-pair name.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#stack_id ⇒ String
The stack ID.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The ID of the instance's subnet. If the stack is running in a VPC, you can use this parameter to override the stack's default subnet ID value and direct OpsWorks Stacks to launch the instance in a different subnet.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#tenancy ⇒ String
The instance's tenancy option. The default option is no tenancy, or
if the instance is running in a VPC, inherit tenancy settings from
the VPC. The following are valid values for this parameter:
dedicated, default, or host. Because there are costs
associated with changes in tenancy options, we recommend that you
research tenancy options before choosing them for your instances.
For more information about dedicated hosts, see Dedicated Hosts
Overview and Amazon EC2 Dedicated Hosts. For more
information about dedicated instances, see Dedicated Instances
and Amazon EC2 Dedicated Instances.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |
#virtualization_type ⇒ String
The instance's virtualization type, paravirtual or hvm.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 |
# File 'lib/aws-sdk-opsworks/types.rb', line 1302 class CreateInstanceRequest < Struct.new( :stack_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :availability_zone, :virtualization_type, :subnet_id, :architecture, :root_device_type, :block_device_mappings, :install_updates_on_boot, :ebs_optimized, :agent_version, :tenancy) SENSITIVE = [] include Aws::Structure end |