Class: Aws::OpsWorks::Types::DescribeStacksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpsWorks::Types::DescribeStacksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opsworks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stack_ids ⇒ Array<String>
An array of stack IDs that specify the stacks to be described.
Instance Attribute Details
#stack_ids ⇒ Array<String>
An array of stack IDs that specify the stacks to be described. If
you omit this parameter, and have permissions to get information
about all stacks, DescribeStacks returns a description of every
stack. If the IAM policy that is attached to an IAM user limits the
DescribeStacks action to specific stack ARNs, this parameter is
required, and the user must specify a stack ARN that is allowed by
the policy. Otherwise, DescribeStacks returns an AccessDenied
error.
2900 2901 2902 2903 2904 |
# File 'lib/aws-sdk-opsworks/types.rb', line 2900 class DescribeStacksRequest < Struct.new( :stack_ids) SENSITIVE = [] include Aws::Structure end |