Class: Aws::OpsWorks::Types::EbsBlockDevice
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpsWorks::Types::EbsBlockDevice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opsworks/types.rb
Overview
Describes an Amazon EBS volume. This data type maps directly to the Amazon EC2 [EbsBlockDevice] data type.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EbsBlockDevice.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Whether the volume is deleted on instance termination.
-
#iops ⇒ Integer
The number of I/O operations per second (IOPS) that the volume supports.
-
#snapshot_id ⇒ String
The snapshot ID.
-
#volume_size ⇒ Integer
The volume size, in GiB.
-
#volume_type ⇒ String
The volume type.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Whether the volume is deleted on instance termination.
3100 3101 3102 3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-opsworks/types.rb', line 3100 class EbsBlockDevice < Struct.new( :snapshot_id, :iops, :volume_size, :volume_type, :delete_on_termination) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of I/O operations per second (IOPS) that the volume supports. For more information, see [EbsBlockDevice].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EbsBlockDevice.html
3100 3101 3102 3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-opsworks/types.rb', line 3100 class EbsBlockDevice < Struct.new( :snapshot_id, :iops, :volume_size, :volume_type, :delete_on_termination) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot ID.
3100 3101 3102 3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-opsworks/types.rb', line 3100 class EbsBlockDevice < Struct.new( :snapshot_id, :iops, :volume_size, :volume_type, :delete_on_termination) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
The volume size, in GiB. For more information, see [EbsBlockDevice].
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EbsBlockDevice.html
3100 3101 3102 3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-opsworks/types.rb', line 3100 class EbsBlockDevice < Struct.new( :snapshot_id, :iops, :volume_size, :volume_type, :delete_on_termination) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
The volume type. gp2 for General Purpose (SSD) volumes, io1 for Provisioned IOPS (SSD) volumes, st1 for Throughput Optimized hard disk drives (HDD), sc1 for Cold HDD,and standard for Magnetic volumes.
If you specify the io1 volume type, you must also specify a value for the Iops attribute. The maximum ratio of provisioned IOPS to requested volume size (in GiB) is 50:1. Amazon Web Services uses the default volume size (in GiB) specified in the AMI attributes to set IOPS to 50 x (volume size).
3100 3101 3102 3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-opsworks/types.rb', line 3100 class EbsBlockDevice < Struct.new( :snapshot_id, :iops, :volume_size, :volume_type, :delete_on_termination) SENSITIVE = [] include Aws::Structure end |