Class: Aws::OpsWorks::Types::UpdateInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpsWorks::Types::UpdateInstanceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opsworks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_version ⇒ String
The default OpsWorks Stacks agent version.
-
#ami_id ⇒ String
The ID of the AMI that was used to create the instance.
-
#architecture ⇒ String
The instance architecture.
-
#auto_scaling_type ⇒ String
For load-based or time-based instances, the type.
-
#ebs_optimized ⇒ Boolean
This property cannot be updated.
-
#hostname ⇒ String
The instance host name.
-
#install_updates_on_boot ⇒ Boolean
Whether to install operating system and package updates when the instance boots.
-
#instance_id ⇒ String
The instance ID.
-
#instance_type ⇒ String
The instance type, such as
t2.micro. -
#layer_ids ⇒ Array<String>
The instance's layer IDs.
-
#os ⇒ String
The instance's operating system, which must be set to one of the following.
-
#ssh_key_name ⇒ String
The instance's Amazon EC2 key name.
Instance Attribute Details
#agent_version ⇒ String
The default OpsWorks Stacks agent version. You have the following options:
-
INHERIT- Use the stack's default agent version setting. -
version_number - Use the specified agent version. This value overrides the stack's default setting. To update the agent version, you must edit the instance configuration and specify a new version. OpsWorks Stacks installs that version on the instance.
The default setting is INHERIT. To specify an agent version, you
must use the complete version number, not the abbreviated number
shown on the console. For a list of available agent version numbers,
call DescribeAgentVersions.
AgentVersion cannot be set to Chef 12.2.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#ami_id ⇒ String
The ID of the AMI that was used to create the instance. The value of this parameter must be the same AMI ID that the instance is already using. You cannot apply a new AMI to an instance by running UpdateInstance. UpdateInstance does not work on instances that are using custom AMIs.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#architecture ⇒ String
The instance architecture. Instance types do not necessarily support both architectures. For a list of the architectures that are supported by the different instance types, see Instance Families and Types.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#auto_scaling_type ⇒ String
For load-based or time-based instances, the type. Windows stacks can use only time-based instances.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#ebs_optimized ⇒ Boolean
This property cannot be updated.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#hostname ⇒ String
The instance host name. The following are character limits for instance host names.
-
Linux-based instances: 63 characters
-
Windows-based instances: 15 characters
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#install_updates_on_boot ⇒ Boolean
Whether to install operating system and package updates when the
instance boots. The default value is true. To control when updates
are installed, set this value to false. You must then update your
instances manually by using CreateDeployment to run the
update_dependencies stack command or by manually running yum
(Amazon Linux) or apt-get (Ubuntu) on the instances.
true, to ensure
that your instances have the latest security updates.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#instance_id ⇒ String
The instance ID.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type, such as t2.micro. For a list of supported
instance types, open the stack in the console, choose Instances,
and choose + Instance. The Size list contains the currently
supported types. For more information, see Instance Families and
Types. The parameter values that you use to specify the various
types are in the API Name column of the Available Instance
Types table.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#layer_ids ⇒ Array<String>
The instance's layer IDs.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#os ⇒ String
The instance's operating system, which must be set to one of the following. You cannot update an instance that is using a custom AMI.
-
A supported Linux operating system: An Amazon Linux version, such as
Amazon Linux 2,Amazon Linux 2018.03,Amazon Linux 2017.09,Amazon Linux 2017.03,Amazon Linux 2016.09,Amazon Linux 2016.03,Amazon Linux 2015.09, orAmazon Linux 2015.03. -
A supported Ubuntu operating system, such as
Ubuntu 18.04 LTS,Ubuntu 16.04 LTS,Ubuntu 14.04 LTS, orUbuntu 12.04 LTS. -
CentOS Linux 7 -
Red Hat Enterprise Linux 7 -
A supported Windows operating system, such as
Microsoft Windows Server 2012 R2 Base,Microsoft Windows Server 2012 R2 with SQL Server Express,Microsoft Windows Server 2012 R2 with SQL Server Standard, orMicrosoft Windows Server 2012 R2 with SQL Server Web.
Not all operating systems are supported with all versions of Chef. For more information about supported operating systems, see OpsWorks Stacks Operating Systems.
The default option is the current Amazon Linux version. If you set
this parameter to Custom, you must use the AmiId parameter to
specify the custom AMI that you want to use. For more information
about how to use custom AMIs with OpsWorks, see Using Custom
AMIs.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |
#ssh_key_name ⇒ String
The instance's Amazon EC2 key name.
5537 5538 5539 5540 5541 5542 5543 5544 5545 5546 5547 5548 5549 5550 5551 5552 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5537 class UpdateInstanceRequest < Struct.new( :instance_id, :layer_ids, :instance_type, :auto_scaling_type, :hostname, :os, :ami_id, :ssh_key_name, :architecture, :install_updates_on_boot, :ebs_optimized, :agent_version) SENSITIVE = [] include Aws::Structure end |