Class: Aws::OpsWorks::Types::UpdateLayerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpsWorks::Types::UpdateLayerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opsworks/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
One or more user-defined key/value pairs to be added to the stack attributes.
-
#auto_assign_elastic_ips ⇒ Boolean
Whether to automatically assign an [Elastic IP address][1] to the layer's instances.
-
#auto_assign_public_ips ⇒ Boolean
For stacks that are running in a VPC, whether to automatically assign a public IP address to the layer's instances.
-
#cloud_watch_logs_configuration ⇒ Types::CloudWatchLogsConfiguration
Specifies CloudWatch Logs configuration options for the layer.
-
#custom_instance_profile_arn ⇒ String
The ARN of an IAM profile to be used for all of the layer's EC2 instances.
-
#custom_json ⇒ String
A JSON-formatted string containing custom stack configuration and deployment attributes to be installed on the layer's instances.
-
#custom_recipes ⇒ Types::Recipes
A
LayerCustomRecipesobject that specifies the layer's custom recipes. -
#custom_security_group_ids ⇒ Array<String>
An array containing the layer's custom security group IDs.
-
#enable_auto_healing ⇒ Boolean
Whether to disable auto healing for the layer.
-
#install_updates_on_boot ⇒ Boolean
Whether to install operating system and package updates when the instance boots.
-
#layer_id ⇒ String
The layer ID.
- #lifecycle_event_configuration ⇒ Types::LifecycleEventConfiguration
-
#name ⇒ String
The layer name, which is used by the console.
-
#packages ⇒ Array<String>
An array of
Packageobjects that describe the layer's packages. -
#shortname ⇒ String
For custom layers only, use this parameter to specify the layer's short name, which is used internally by OpsWorks Stacks and by Chef.
-
#use_ebs_optimized_instances ⇒ Boolean
Whether to use Amazon EBS-optimized instances.
-
#volume_configurations ⇒ Array<Types::VolumeConfiguration>
A
VolumeConfigurationsobject that describes the layer's Amazon EBS volumes.
Instance Attribute Details
#attributes ⇒ Hash<String,String>
One or more user-defined key/value pairs to be added to the stack attributes.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#auto_assign_elastic_ips ⇒ Boolean
Whether to automatically assign an Elastic IP address to the layer's instances. For more information, see How to Edit a Layer.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#auto_assign_public_ips ⇒ Boolean
For stacks that are running in a VPC, whether to automatically assign a public IP address to the layer's instances. For more information, see How to Edit a Layer.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#cloud_watch_logs_configuration ⇒ Types::CloudWatchLogsConfiguration
Specifies CloudWatch Logs configuration options for the layer. For more information, see CloudWatchLogsLogStream.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#custom_instance_profile_arn ⇒ String
The ARN of an IAM profile to be used for all of the layer's EC2 instances. For more information about IAM ARNs, see Using Identifiers.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#custom_json ⇒ String
A JSON-formatted string containing custom stack configuration and deployment attributes to be installed on the layer's instances. For more information, see Using Custom JSON.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#custom_recipes ⇒ Types::Recipes
A LayerCustomRecipes object that specifies the layer's custom
recipes.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#custom_security_group_ids ⇒ Array<String>
An array containing the layer's custom security group IDs.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#enable_auto_healing ⇒ Boolean
Whether to disable auto healing for the layer.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#install_updates_on_boot ⇒ Boolean
Whether to install operating system and package updates when the
instance boots. The default value is true. To control when updates
are installed, set this value to false. You must then update your
instances manually by using CreateDeployment to run the
update_dependencies stack command or manually running yum
(Amazon Linux) or apt-get (Ubuntu) on the instances.
true, to ensure
that your instances have the latest security updates.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#layer_id ⇒ String
The layer ID.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#lifecycle_event_configuration ⇒ Types::LifecycleEventConfiguration
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The layer name, which is used by the console. Layer names can be a maximum of 32 characters.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#packages ⇒ Array<String>
An array of Package objects that describe the layer's packages.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#shortname ⇒ String
For custom layers only, use this parameter to specify the layer's short name, which is used internally by OpsWorks Stacks and by Chef. The short name is also used as the name for the directory where your app files are installed. It can have a maximum of 32 characters and must be in the following format: /\A[a-z0-9\-\_\.]+\Z/.
Built-in layer short names are defined by OpsWorks Stacks. For more information, see the Layer reference in the OpsWorks User Guide.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#use_ebs_optimized_instances ⇒ Boolean
Whether to use Amazon EBS-optimized instances.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |
#volume_configurations ⇒ Array<Types::VolumeConfiguration>
A VolumeConfigurations object that describes the layer's Amazon
EBS volumes.
5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 5687 5688 5689 5690 5691 5692 5693 5694 5695 |
# File 'lib/aws-sdk-opsworks/types.rb', line 5675 class UpdateLayerRequest < Struct.new( :layer_id, :name, :shortname, :attributes, :cloud_watch_logs_configuration, :custom_instance_profile_arn, :custom_json, :custom_security_group_ids, :packages, :volume_configurations, :enable_auto_healing, :auto_assign_elastic_ips, :auto_assign_public_ips, :custom_recipes, :install_updates_on_boot, :use_ebs_optimized_instances, :lifecycle_event_configuration) SENSITIVE = [] include Aws::Structure end |