Class: Aws::OpsWorks::Waiters::AppExists

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-opsworks/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ AppExists

Returns a new instance of AppExists.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 1
  • :before_attempt (Proc)
  • :before_wait (Proc)


89
90
# File 'lib/aws-sdk-opsworks/waiters.rb', line 89

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



119
120
121
# File 'lib/aws-sdk-opsworks/waiters.rb', line 119

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeAppsResult

Returns a response object which responds to the following methods:

  • #apps => Array<Types::App>

Options Hash (params):

  • :stack_id (String)

    The app stack ID. If you use this parameter, DescribeApps returns a description of the apps in the specified stack.

  • :app_ids (Array<String>)

    An array of app IDs for the apps to be described. If you use this parameter, DescribeApps returns a description of the specified apps. Otherwise, it returns a description of every app.

Returns:



114
# File 'lib/aws-sdk-opsworks/waiters.rb', line 114

def wait: (