Class: Aws::OpsWorks::Waiters::DeploymentSuccessful

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-opsworks/waiters.rb,
sig/waiters.rbs

Overview

Wait until a deployment has completed successfully.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ DeploymentSuccessful

Returns a new instance of DeploymentSuccessful.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


132
133
# File 'lib/aws-sdk-opsworks/waiters.rb', line 132

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



164
165
166
# File 'lib/aws-sdk-opsworks/waiters.rb', line 164

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeDeploymentsResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :stack_id (String)

    The stack ID. If you include this parameter, the command returns a description of the commands associated with the specified stack.

  • :app_id (String)

    The app ID. If you include this parameter, the command returns a description of the commands associated with the specified app.

  • :deployment_ids (Array<String>)

    An array of deployment IDs to be described. If you include this parameter, the command returns a description of the specified deployments. Otherwise, it returns a description of every deployment.

Returns:



159
# File 'lib/aws-sdk-opsworks/waiters.rb', line 159

def wait: (