Class: Aws::OpsWorks::Waiters::InstanceStopped

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-opsworks/waiters.rb,
sig/waiters.rbs

Overview

Wait until OpsWorks instance is stopped.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ InstanceStopped

Returns a new instance of InstanceStopped.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


345
346
# File 'lib/aws-sdk-opsworks/waiters.rb', line 345

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



419
420
421
# File 'lib/aws-sdk-opsworks/waiters.rb', line 419

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DescribeInstancesResult

Returns a response object which responds to the following methods:

Options Hash (params):

  • :stack_id (String)

    A stack ID. If you use this parameter, DescribeInstances returns descriptions of the instances associated with the specified stack.

  • :layer_id (String)

    A layer ID. If you use this parameter, DescribeInstances returns descriptions of the instances associated with the specified layer.

  • :instance_ids (Array<String>)

    An array of instance IDs to be described. If you use this parameter, DescribeInstances returns a description of the specified instances. Otherwise, it returns a description of every instance.

Returns:



414
# File 'lib/aws-sdk-opsworks/waiters.rb', line 414

def wait: (