Class: Aws::OpsWorks::Waiters::AppExists
- Inherits:
-
Object
- Object
- Aws::OpsWorks::Waiters::AppExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-opsworks/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ AppExists
constructor
A new instance of AppExists.
-
#wait(params = {}) ⇒ Types::DescribeAppsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ AppExists
Returns a new instance of AppExists.
89 90 |
# File 'lib/aws-sdk-opsworks/waiters.rb', line 89
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
119 120 121 |
# File 'lib/aws-sdk-opsworks/waiters.rb', line 119 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeAppsResult
Returns a response object which responds to the following methods:
- #apps => Array<Types::App>
114 |
# File 'lib/aws-sdk-opsworks/waiters.rb', line 114
def wait: (
|