Class: Aws::OpsWorks::Waiters::DeploymentSuccessful
- Inherits:
-
Object
- Object
- Aws::OpsWorks::Waiters::DeploymentSuccessful
- Defined in:
- lib/aws-sdk-opsworks/waiters.rb,
sig/waiters.rbs
Overview
Wait until a deployment has completed successfully.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ DeploymentSuccessful
constructor
A new instance of DeploymentSuccessful.
-
#wait(params = {}) ⇒ Types::DescribeDeploymentsResult
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ DeploymentSuccessful
Returns a new instance of DeploymentSuccessful.
132 133 |
# File 'lib/aws-sdk-opsworks/waiters.rb', line 132
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
164 165 166 |
# File 'lib/aws-sdk-opsworks/waiters.rb', line 164 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeDeploymentsResult
Returns a response object which responds to the following methods:
- #deployments => Array<Types::Deployment>
159 |
# File 'lib/aws-sdk-opsworks/waiters.rb', line 159
def wait: (
|